@@ -3,12 +3,6 @@
 
 package config
 
-import (
-	"fmt"
-	"os"
-	"path/filepath"
-)
-
 const (
 	// DefaultRefreshRate represents the refresh interval.
 	DefaultRefreshRate = 2 // secs
@@ -21,7 +15,7 @@ const (
 )
 
 // DefaultLogFile represents the default K9s log file.
-var DefaultLogFile = filepath.Join(os.TempDir(), fmt.Sprintf("k9s-%s.log", MustK9sUser()))
+// var DefaultLogFile = filepath.Join(os.TempDir(), fmt.Sprintf("k9s-%s.log", MustK9sUser()))
 
 // Flags represents K9s configuration flags.
 type Flags struct {
@@ -43,7 +37,7 @@ func NewFlags() *Flags {
 	return &Flags{
 		RefreshRate:   intPtr(DefaultRefreshRate),
 		LogLevel:      strPtr(DefaultLogLevel),
-		LogFile:       strPtr(DefaultLogFile),
+		LogFile:       strPtr(AppLogFile),
 		Headless:      boolPtr(false),
 		Logoless:      boolPtr(false),
 		Command:       strPtr(DefaultCommand),
@@ -51,7 +45,7 @@ func NewFlags() *Flags {
 		ReadOnly:      boolPtr(false),
 		Write:         boolPtr(false),
 		Crumbsless:    boolPtr(false),
-		ScreenDumpDir: strPtr(K9sDefaultScreenDumpDir),
+		ScreenDumpDir: strPtr(AppDumpsDir),
 	}
 }
 
