@@ -5,17 +5,13 @@ package config
 
 import (
 	"os"
-	"path/filepath"
 
 	"gopkg.in/yaml.v2"
 )
 
-// K9sHotKeys manages K9s hotKeys.
-var K9sHotKeys = YamlExtension(filepath.Join(K9sHome(), "hotkey.yml"))
-
 // HotKeys represents a collection of plugins.
 type HotKeys struct {
-	HotKey map[string]HotKey `yaml:"hotKey"`
+	HotKey map[string]HotKey `yaml:"hotKeys"`
 }
 
 // HotKey describes a K9s hotkey.
@@ -34,7 +30,7 @@ func NewHotKeys() HotKeys {
 
 // Load K9s plugins.
 func (h HotKeys) Load() error {
-	return h.LoadHotKeys(K9sHotKeys)
+	return h.LoadHotKeys(AppHotKeysFile)
 }
 
 // LoadHotKeys loads plugins from a given file.
