@@ -62,12 +62,14 @@ func (c *conn) ValidNamespaces() ([]v1.Namespace, error)              { return n
 func (c *conn) SupportsRes(grp string, versions []string) (string, bool, error) {
 	return "", false, nil
 }
-func (c *conn) ServerVersion() (*version.Info, error)             { return nil, nil }
-func (c *conn) CurrentNamespaceName() (string, error)             { return "", nil }
-func (c *conn) CanI(ns, gvr string, verbs []string) (bool, error) { return true, nil }
-func (c *conn) ActiveCluster() string                             { return "" }
-func (c *conn) ActiveNamespace() string                           { return "" }
-func (c *conn) IsActiveNamespace(string) bool                     { return false }
+func (c *conn) ServerVersion() (*version.Info, error)               { return nil, nil }
+func (c *conn) CurrentNamespaceName() (string, error)               { return "", nil }
+func (c *conn) CanI(ns, gvr string, verbs []string) (bool, error)   { return true, nil }
+func (c *conn) ActiveContext() string                               { return "" }
+func (c *conn) ActiveNamespace() string                             { return "" }
+func (c *conn) IsValidNamespace(string) bool                        { return true }
+func (c *conn) ValidNamespaceNames() (client.NamespaceNames, error) { return nil, nil }
+func (c *conn) IsActiveNamespace(string) bool                       { return false }
 
 type podFactory struct{}
 
