@@ -22,7 +22,7 @@ func (Alias) Header(ns string) Header {
 	return Header{
 		HeaderColumn{Name: "RESOURCE"},
 		HeaderColumn{Name: "COMMAND"},
-		HeaderColumn{Name: "APIGROUP"},
+		HeaderColumn{Name: "API-GROUP"},
 	}
 }
 
