@@ -16,5 +16,5 @@ func TestDaemonSetRender(t *testing.T) {
 
 	assert.NoError(t, c.Render(load(t, "ds"), "", &r))
 	assert.Equal(t, "kube-system/fluentd-gcp-v3.2.0", r.ID)
-	assert.Equal(t, render.Fields{"kube-system", "fluentd-gcp-v3.2.0", "2", "2", "2", "2", "2"}, r.Fields[:7])
+	assert.Equal(t, render.Fields{"kube-system", "fluentd-gcp-v3.2.0", "0", "2", "2", "2", "2", "2"}, r.Fields[:8])
 }
