@@ -5,14 +5,13 @@ package render_test
 
 import (
 	"testing"
+	"time"
 
 	"github.com/derailed/k9s/internal/render"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestPortForwardRender(t *testing.T) {
-	var p render.PortForward
-	var r render.Row
 	o := render.ForwardRes{
 		Forwarder: fwd{},
 		Config: render.BenchCfg{
@@ -23,6 +22,8 @@ func TestPortForwardRender(t *testing.T) {
 		},
 	}
 
+	var p render.PortForward
+	var r render.Row
 	assert.Nil(t, p.Render(o, "fred", &r))
 	assert.Equal(t, "blee/fred", r.ID)
 	assert.Equal(t, render.Fields{
@@ -34,8 +35,7 @@ func TestPortForwardRender(t *testing.T) {
 		"1",
 		"1",
 		"",
-		"2m",
-	}, r.Fields)
+	}, r.Fields[:8])
 }
 
 // Helpers...
@@ -62,6 +62,6 @@ func (f fwd) Active() bool {
 	return true
 }
 
-func (f fwd) Age() string {
-	return "2m"
+func (f fwd) Age() time.Time {
+	return testTime()
 }
