@@ -60,6 +60,9 @@ func NewLiveView(app *App, title string, m model.ResourceViewer) *LiveView {
 	return &v
 }
 
+func (v *LiveView) SetFilter(string)                 {}
+func (v *LiveView) SetLabelFilter(map[string]string) {}
+
 // Init initializes the viewer.
 func (v *LiveView) Init(_ context.Context) error {
 	if v.title != "" {
@@ -100,36 +103,17 @@ func (v *LiveView) ResourceFailed(err error) {
 	v.text.SetText(cowTalk(err.Error(), x+w))
 }
 
-func (*LiveView) linesWithRegions(lines []string, matches fuzzy.Matches) []string {
-	ll := make([]string, len(lines))
-	copy(ll, lines)
-	offsetForLine := make(map[int]int)
-	for i, m := range matches {
-		loc, line := m.MatchedIndexes, ll[m.Index]
-		if len(loc) < 2 {
-			continue
-		}
-		offset := offsetForLine[m.Index]
-
-		loc[0], loc[1] = loc[0]+offset, loc[1]+offset
-		regionStr := `<<<"search_` + strconv.Itoa(i) + `">>>` + line[loc[0]:loc[1]] + `<<<"">>>`
-		ll[m.Index] = line[:loc[0]] + regionStr + line[loc[1]:]
-		offsetForLine[m.Index] += len(regionStr) - (loc[1] - loc[0])
-	}
-	return ll
-}
-
 // ResourceChanged notifies when the filter changes.
 func (v *LiveView) ResourceChanged(lines []string, matches fuzzy.Matches) {
 	v.app.QueueUpdateDraw(func() {
 		v.text.SetTextAlign(tview.AlignLeft)
-		v.maxRegions = len(matches)
+		v.currentRegion, v.maxRegions = 0, len(matches)
 
 		if v.text.GetText(true) == "" {
 			v.text.ScrollToBeginning()
 		}
 
-		lines = v.linesWithRegions(lines, matches)
+		lines = linesWithRegions(lines, matches)
 		v.text.SetText(colorizeYAML(v.app.Styles.Views().Yaml, strings.Join(lines, "\n")))
 		v.text.Highlight()
 		if v.currentRegion < v.maxRegions {
@@ -373,7 +357,7 @@ func (v *LiveView) resetCmd(evt *tcell.EventKey) *tcell.EventKey {
 
 func (v *LiveView) saveCmd(evt *tcell.EventKey) *tcell.EventKey {
 	name := fmt.Sprintf("%s--%s", strings.Replace(v.model.GetPath(), "/", "-", 1), strings.ToLower(v.title))
-	if _, err := saveYAML(v.app.Config.K9s.GetScreenDumpDir(), v.app.Config.K9s.CurrentContextDir(), name, sanitizeEsc(v.text.GetText(true))); err != nil {
+	if _, err := saveYAML(v.app.Config.K9s.ActiveScreenDumpsDir(), name, sanitizeEsc(v.text.GetText(true))); err != nil {
 		v.app.Flash().Err(err)
 	} else {
 		v.app.Flash().Infof("File %q saved successfully!", name)
