@@ -5,11 +5,10 @@ package view
 
 import (
 	"context"
-	"path/filepath"
 
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/config"
+	"github.com/derailed/k9s/internal/config/data"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
 	"github.com/rs/zerolog/log"
@@ -28,7 +27,7 @@ func NewScreenDump(gvr client.GVR) ResourceViewer {
 	s.GetTable().SetBorderFocusColor(tcell.ColorSteelBlue)
 	s.GetTable().SetSelectedStyle(tcell.StyleDefault.Foreground(tcell.ColorWhite).Background(tcell.ColorRoyalBlue).Attributes(tcell.AttrNone))
 	s.GetTable().SetSortCol(ageCol, true)
-	s.GetTable().SelectRow(1, true)
+	s.GetTable().SelectRow(1, 0, true)
 	s.GetTable().SetEnterFn(s.edit)
 	s.SetContextFn(s.dirContext)
 
@@ -36,8 +35,8 @@ func NewScreenDump(gvr client.GVR) ResourceViewer {
 }
 
 func (s *ScreenDump) dirContext(ctx context.Context) context.Context {
-	dir := filepath.Join(s.App().Config.K9s.GetScreenDumpDir(), s.App().Config.K9s.CurrentContextDir())
-	if err := config.EnsureFullPath(dir, config.DefaultDirMod); err != nil {
+	dir := s.App().Config.K9s.ActiveScreenDumpsDir()
+	if err := data.EnsureFullPath(dir, data.DefaultDirMod); err != nil {
 		s.App().Flash().Err(err)
 		return ctx
 	}
@@ -45,7 +44,7 @@ func (s *ScreenDump) dirContext(ctx context.Context) context.Context {
 	return context.WithValue(ctx, internal.KeyDir, dir)
 }
 
-func (s *ScreenDump) edit(app *App, model ui.Tabular, gvr, path string) {
+func (s *ScreenDump) edit(app *App, _ ui.Tabular, _ client.GVR, path string) {
 	log.Debug().Msgf("ScreenDump selection is %q", path)
 
 	s.Stop()
